@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Partition a musical duration
 
-our $VERSION = '0.0100';
+our $VERSION = '0.0101';
 
 use Moo;
 use strictures 2;
@@ -108,7 +108,7 @@ Music::Duration::Partition - Partition a musical duration
 
 =head1 VERSION
 
-version 0.0100
+version 0.0101
 
 =head1 SYNOPSIS
 
@@ -133,8 +133,9 @@ version 0.0100
 
 =head1 DESCRIPTION
 
-C<Music::Duration::Partition> partitions a musical duration into
-smaller durations that equal the original given duration.
+C<Music::Duration::Partition> partitions a musical duration (the
+B<size> attribute) into smaller durations drawn from the B<pool> of
+possible durations.
 
 =head1 ATTRIBUTES
 
@@ -158,9 +159,9 @@ Default: C<reverse %MIDI::Simple::Length>
 
   $size = $mdp->size;
 
-L<MIDI::Simple::Length> value for the duration of a whole note.
+The value of the duration to partition.
 
-Default: C<4>
+Default: C<4> (whole note)
 
 =head2 pool
 
@@ -175,8 +176,6 @@ Default: C<[ keys %MIDI::Simple::Length ]>
 
   $threshold = $mdp->threshold;
 
-The B<size> minus the smallest B<pool> duration value.
-
 This is a computed attribute.
 
 =head1 METHODS
